===============================
Wagtail Form Blocks
===============================


.. image:: https://img.shields.io/pypi/v/wagtailformblocks.svg
        :target: https://pypi.python.org/pypi/wagtailformblocks

.. image:: https://readthedocs.org/projects/wagtailformblocks/badge/?version=latest
        :target: https://wagtailformblocks.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://travis-ci.org/LUKKIEN/wagtailformblocks.svg?branch=master
    :target: https://travis-ci.org/LUKKIEN/wagtailformblocks

.. image:: https://codecov.io/gh/LUKKIEN/wagtailformblocks/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/LUKKIEN/wagtailformblocks

A Wagtail module that provides content blocks to display and process user defined forms


* Documentation: https://wagtailformblocks.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
